@@ -1,8 +1,8 @@
-/* 
+/*
  * tkMacOSXHLEvents.c --
  *
- *        Implements high level event support for the Macintosh.  Currently, 
- *        the only event that really does anything is the Quit event.
+ *	Implements high level event support for the Macintosh. Currently,
+ *	the only event that really does anything is the Quit event.
  *
  * Copyright (c) 1995-1997 Sun Microsystems, Inc.
  * Copyright 2001, Apple Computer, Inc.
@@ -11,21 +11,21 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * RCS: @(#) $Id: tkMacOSXHLEvents.c,v 1.5.2.9 2006/05/12 18:18:52 das Exp $
+ * RCS: @(#) $Id: tkMacOSXHLEvents.c,v 1.5.2.11 2007/06/29 03:22:02 das Exp $
  */
 
-#include "tkMacOSXInt.h"
+#include "tkMacOSXPrivate.h"
 
 /*
  * This is a Tcl_Event structure that the Quit AppleEvent handler
  * uses to schedule the ReallyKillMe function.
  */
- 
+
 typedef struct KillEvent {
-    Tcl_Event header;           /* Information that is standard for
-                                 * all events. */
-    Tcl_Interp *interp;         /* Interp that was passed to the
-                                 * Quit AppleEvent */
+    Tcl_Event header;		/* Information that is standard for
+				 * all events. */
+    Tcl_Interp *interp;		/* Interp that was passed to the
+				 * Quit AppleEvent */
 } KillEvent;
 
 /*
@@ -49,68 +49,66 @@ static OSErr PrefsHandler(const AppleEvent * event, AppleEvent * reply,
 
 static int MissedAnyParameters(const AppleEvent *theEvent);
 static int ReallyKillMe(Tcl_Event *eventPtr, int flags);
-static OSErr FSRefToDString(const FSRef *fsref, Tcl_DString *ds);
+static OSStatus FSRefToDString(const FSRef *fsref, Tcl_DString *ds);
 
 /*
  *----------------------------------------------------------------------
  *
  * TkMacOSXInitAppleEvents --
  *
- *        Initilize the Apple Events on the Macintosh.  This registers the
- *        core event handlers.
+ *	Initilize the Apple Events on the Macintosh. This registers the
+ *	core event handlers.
  *
  * Results:
- *        None.
+ *	None.
  *
  * Side effects:
- *        None.
+ *	None.
  *
  *----------------------------------------------------------------------
  */
 
-void 
+void
 TkMacOSXInitAppleEvents(
-    Tcl_Interp *interp)                /* Interp to handle basic events. */
+    Tcl_Interp *interp)		       /* Interp to handle basic events. */
 {
-    OSErr err;
-    AEEventHandlerUPP        OappHandlerUPP, RappHandlerUPP, OdocHandlerUPP,
-        PrintHandlerUPP, QuitHandlerUPP, ScriptHandlerUPP,
-        PrefsHandlerUPP;
+    AEEventHandlerUPP	     OappHandlerUPP, RappHandlerUPP, OdocHandlerUPP,
+	    PrintHandlerUPP, QuitHandlerUPP, ScriptHandlerUPP, PrefsHandlerUPP;
     static Boolean initialized = FALSE;
 
     if (!initialized) {
-        initialized = TRUE;
+	initialized = TRUE;
 
 	/*
 	 * Install event handlers for the core apple events.
 	 */
 	QuitHandlerUPP = NewAEEventHandlerUPP(QuitHandler);
-	err = AEInstallEventHandler(kCoreEventClass, kAEQuitApplication,
+	ChkErr(AEInstallEventHandler, kCoreEventClass, kAEQuitApplication,
 		QuitHandlerUPP, (long) interp, false);
 
 	OappHandlerUPP = NewAEEventHandlerUPP(OappHandler);
-	err = AEInstallEventHandler(kCoreEventClass, kAEOpenApplication,
+	ChkErr(AEInstallEventHandler, kCoreEventClass, kAEOpenApplication,
 		OappHandlerUPP, (long) interp, false);
 
 	RappHandlerUPP = NewAEEventHandlerUPP(RappHandler);
-	err = AEInstallEventHandler(kCoreEventClass, kAEReopenApplication,
+	ChkErr(AEInstallEventHandler, kCoreEventClass, kAEReopenApplication,
 		RappHandlerUPP, (long) interp, false);
 
 	OdocHandlerUPP = NewAEEventHandlerUPP(OdocHandler);
-	err = AEInstallEventHandler(kCoreEventClass, kAEOpenDocuments,
+	ChkErr(AEInstallEventHandler, kCoreEventClass, kAEOpenDocuments,
 		OdocHandlerUPP, (long) interp, false);
 
 	PrintHandlerUPP = NewAEEventHandlerUPP(PrintHandler);
-	err = AEInstallEventHandler(kCoreEventClass, kAEPrintDocuments,
+	ChkErr(AEInstallEventHandler, kCoreEventClass, kAEPrintDocuments,
 		PrintHandlerUPP, (long) interp, false);
 
 	PrefsHandlerUPP = NewAEEventHandlerUPP(PrefsHandler);
-	err = AEInstallEventHandler(kCoreEventClass, kAEShowPreferences,
+	ChkErr(AEInstallEventHandler, kCoreEventClass, kAEShowPreferences,
 		PrefsHandlerUPP, (long) interp, false);
 
 	if (interp) {
 	    ScriptHandlerUPP = NewAEEventHandlerUPP(ScriptHandler);
-	    err = AEInstallEventHandler(kAEMiscStandards, kAEDoScript,
+	    ChkErr(AEInstallEventHandler, kAEMiscStandards, kAEDoScript,
 		ScriptHandlerUPP, (long) interp, false);
 	}
     }
@@ -121,13 +119,13 @@ TkMacOSXInitAppleEvents(
  *
  * TkMacOSXDoHLEvent --
  *
- *        Dispatch incomming highlevel events.
+ *	Dispatch incomming highlevel events.
  *
  * Results:
- *        None.
+ *	None.
  *
  * Side effects:
- *        Depends on the incoming event.
+ *	Depends on the incoming event.
  *
  *----------------------------------------------------------------------
  */
@@ -142,46 +140,63 @@ TkMacOSXDoHLEvent(
 /*
  *----------------------------------------------------------------------
  *
- * QuitHandler, OappHandler, etc. --
+ * QuitHandler --
  *
- *        These are the core Apple event handlers.
+ *	This is the 'quit' core Apple event handler.
  *
  * Results:
- *        None.
+ *	None.
  *
  * Side effects:
- *        None.
+ *	None.
  *
  *----------------------------------------------------------------------
  */
-static OSErr
-QuitHandler (
+
+OSErr
+QuitHandler(
     const AppleEvent * event,
     AppleEvent * reply,
     long handlerRefcon)
 {
     Tcl_Interp *interp = (Tcl_Interp *) handlerRefcon;
     KillEvent *eventPtr;
-    
+
     if (interp) {
 	/*
 	 * Call the exit command from the event loop, since you are not supposed
-	 * to call ExitToShell in an Apple Event Handler.  We put this at the head
+	 * to call ExitToShell in an Apple Event Handler. We put this at the head
 	 * of Tcl's event queue because this message usually comes when the Mac is
 	 * shutting down, and we want to kill the shell as quickly as possible.
 	 */
-	
+
 	eventPtr = (KillEvent *) ckalloc(sizeof(KillEvent));
 	eventPtr->header.proc = ReallyKillMe;
 	eventPtr->interp = interp;
-	 
+
 	Tcl_QueueEvent((Tcl_Event *) eventPtr, TCL_QUEUE_HEAD);
     }
     return noErr;
 }
 
-static OSErr 
-OappHandler (
+/*
+ *----------------------------------------------------------------------
+ *
+ * OappHandler --
+ *
+ *	This is the 'oapp' core Apple event handler.
+ *
+ * Results:
+ *	None.
+ *
+ * Side effects:
+ *	None.
+ *
+ *----------------------------------------------------------------------
+ */
+
+OSErr
+OappHandler(
     const AppleEvent * event,
     AppleEvent * reply,
     long handlerRefcon)
@@ -196,8 +211,24 @@ OappHandler (
     return noErr;
 }
 
-static OSErr 
-RappHandler (
+/*
+ *----------------------------------------------------------------------
+ *
+ * RappHandler --
+ *
+ *	This is the 'rapp' core Apple event handler.
+ *
+ * Results:
+ *	None.
+ *
+ * Side effects:
+ *	None.
+ *
+ *----------------------------------------------------------------------
+ */
+
+OSErr
+RappHandler(
     const AppleEvent * event,
     AppleEvent * reply,
     long handlerRefcon)
@@ -205,18 +236,34 @@ RappHandler (
     Tcl_CmdInfo dummy;
     Tcl_Interp *interp = (Tcl_Interp *) handlerRefcon;
     ProcessSerialNumber thePSN = {0, kCurrentProcess};
-    OSStatus status = SetFrontProcess(&thePSN);
-    
+    OSStatus err = ChkErr(SetFrontProcess, &thePSN);
+
     if (interp &&
 	    Tcl_GetCommandInfo(interp, "::tk::mac::ReopenApplication", &dummy)) {
 	Tcl_GlobalEval(interp, "::tk::mac::ReopenApplication");
     }
-    return status;
+    return err;
 }
 
-/* Called when the user selects 'Preferences...' in MacOS X */
-static OSErr 
-PrefsHandler (
+/*
+ *----------------------------------------------------------------------
+ *
+ * PrefsHandler --
+ *
+ *	This is the 'pref' core Apple event handler.
+ *	Called when the user selects 'Preferences...' in MacOS X
+ *
+ * Results:
+ *	None.
+ *
+ * Side effects:
+ *	None.
+ *
+ *----------------------------------------------------------------------
+ */
+
+OSErr
+PrefsHandler(
     const AppleEvent * event,
     AppleEvent * reply,
     long handlerRefcon)
@@ -231,8 +278,24 @@ PrefsHandler (
     return noErr;
 }
 
-static OSErr 
-OdocHandler (
+/*
+ *----------------------------------------------------------------------
+ *
+ * OdocHandler --
+ *
+ *	This is the 'odoc' core Apple event handler.
+ *
+ * Results:
+ *	None.
+ *
+ * Side effects:
+ *	None.
+ *
+ *----------------------------------------------------------------------
+ */
+
+OSErr
+OdocHandler(
     const AppleEvent * event,
     AppleEvent * reply,
     long handlerRefcon)
@@ -240,7 +303,7 @@ OdocHandler (
     Tcl_Interp *interp = (Tcl_Interp *) handlerRefcon;
     AEDescList fileSpecList;
     FSRef file;
-    OSErr err;
+    OSStatus err;
     DescType type;
     Size actual;
     long count;
@@ -255,56 +318,73 @@ OdocHandler (
      * the open document procedure doesn't exist.
      */
 
-    if ((interp == NULL) || 
-            (Tcl_GetCommandInfo(interp, "::tk::mac::OpenDocument", &dummy)) == 0) {
-            return noErr;
+    if ((interp == NULL) ||
+	    (Tcl_GetCommandInfo(interp, "::tk::mac::OpenDocument", &dummy)) == 0) {
+	    return noErr;
     }
-    
+
     /*
      * If we get any errors wil retrieving our parameters
      * we just return with no error.
      */
 
-    err = AEGetParamDesc(event, keyDirectObject,
-            typeAEList, &fileSpecList);
+    err = ChkErr(AEGetParamDesc, event, keyDirectObject, typeAEList,
+	    &fileSpecList);
     if (err != noErr) {
-        return noErr;
+	return noErr;
     }
 
     err = MissedAnyParameters(event);
     if (err != noErr) {
-        return noErr;
+	return noErr;
     }
 
-    err = AECountItems(&fileSpecList, &count);
+    err = ChkErr(AECountItems, &fileSpecList, &count);
     if (err != noErr) {
-        return noErr;
+	return noErr;
     }
 
     Tcl_DStringInit(&command);
     Tcl_DStringAppend(&command, "::tk::mac::OpenDocument", -1);
     for (index = 1; index <= count; index++) {
-        err = AEGetNthPtr(&fileSpecList, index, typeFSRef,
-                &keyword, &type, (Ptr) &file, sizeof(FSRef), &actual);
-        if ( err != noErr ) {
-            continue;
-        }
+	err = ChkErr(AEGetNthPtr, &fileSpecList, index, typeFSRef,
+		&keyword, &type, (Ptr) &file, sizeof(FSRef), &actual);
+	if ( err != noErr ) {
+	    continue;
+	}
 
-        err = FSRefToDString(&file, &pathName);
-        if (err == noErr) {
-            Tcl_DStringAppendElement(&command, Tcl_DStringValue(&pathName));
-            Tcl_DStringFree(&pathName);
-        }
+	err = ChkErr(FSRefToDString, &file, &pathName);
+	if (err == noErr) {
+	    Tcl_DStringAppendElement(&command, Tcl_DStringValue(&pathName));
+	    Tcl_DStringFree(&pathName);
+	}
     }
-    
-    Tcl_GlobalEval(interp, Tcl_DStringValue(&command));
+
+    Tcl_EvalEx(interp, Tcl_DStringValue(&command), Tcl_DStringLength(&command),
+	    TCL_EVAL_GLOBAL);
 
     Tcl_DStringFree(&command);
     return noErr;
 }
 
-static OSErr 
-PrintHandler (
+/*
+ *----------------------------------------------------------------------
+ *
+ * PrintHandler --
+ *
+ *	This is the 'pdoc' core Apple event handler.
+ *
+ * Results:
+ *	None.
+ *
+ * Side effects:
+ *	None.
+ *
+ *----------------------------------------------------------------------
+ */
+
+OSErr
+PrintHandler(
     const AppleEvent * event,
     AppleEvent * reply,
     long handlerRefcon)
@@ -312,7 +392,7 @@ PrintHandler (
     Tcl_Interp *interp = (Tcl_Interp *) handlerRefcon;
     AEDescList fileSpecList;
     FSRef file;
-    OSErr err;
+    OSStatus err;
     DescType type;
     Size actual;
     long count;
@@ -327,49 +407,50 @@ PrintHandler (
      * the print document procedure doesn't exist.
      */
 
-    if ((interp == NULL) || 
-            (Tcl_GetCommandInfo(interp, "::tk::mac::PrintDocument", &dummy)) == 0) {
-            return noErr;
+    if ((interp == NULL) ||
+	    (Tcl_GetCommandInfo(interp, "::tk::mac::PrintDocument", &dummy)) == 0) {
+	    return noErr;
     }
-    
+
     /*
      * If we get any errors wil retrieving our parameters
      * we just return with no error.
      */
 
-    err = AEGetParamDesc(event, keyDirectObject,
-            typeAEList, &fileSpecList);
+    err = ChkErr(AEGetParamDesc, event, keyDirectObject, typeAEList,
+	    &fileSpecList);
     if (err != noErr) {
-        return noErr;
+	return noErr;
     }
 
-    err = MissedAnyParameters(event);
+    err = ChkErr(MissedAnyParameters, event);
     if (err != noErr) {
-        return noErr;
+	return noErr;
     }
 
-    err = AECountItems(&fileSpecList, &count);
+    err = ChkErr(AECountItems, &fileSpecList, &count);
     if (err != noErr) {
-        return noErr;
+	return noErr;
     }
 
     Tcl_DStringInit(&command);
     Tcl_DStringAppend(&command, "::tk::mac::PrintDocument", -1);
     for (index = 1; index <= count; index++) {
-        err = AEGetNthPtr(&fileSpecList, index, typeFSRef,
-                &keyword, &type, (Ptr) &file, sizeof(FSRef), &actual);
-        if ( err != noErr ) {
-            continue;
-        }
+	err = ChkErr(AEGetNthPtr, &fileSpecList, index, typeFSRef, &keyword,
+		&type, (Ptr) &file, sizeof(FSRef), &actual);
+	if ( err != noErr ) {
+	    continue;
+	}
 
-        err = FSRefToDString(&file, &pathName);
-        if (err == noErr) {
-            Tcl_DStringAppendElement(&command, Tcl_DStringValue(&pathName));
-            Tcl_DStringFree(&pathName);
-        }
+	err = ChkErr(FSRefToDString, &file, &pathName);
+	if (err == noErr) {
+	    Tcl_DStringAppendElement(&command, Tcl_DStringValue(&pathName));
+	    Tcl_DStringFree(&pathName);
+	}
     }
-    
-    Tcl_GlobalEval(interp, Tcl_DStringValue(&command));
+
+    Tcl_EvalEx(interp, Tcl_DStringValue(&command), Tcl_DStringLength(&command),
+	    TCL_EVAL_GLOBAL);
 
     Tcl_DStringFree(&command);
     return noErr;
@@ -380,24 +461,24 @@ PrintHandler (
  *
  * ScriptHandler --
  *
- *        This handler process the script event.  
+ *	This handler process the script event.
  *
  * Results:
- *        Schedules the given event to be processed.
+ *	Schedules the given event to be processed.
  *
  * Side effects:
- *        None.
+ *	None.
  *
  *----------------------------------------------------------------------
  */
 
-static OSErr 
-ScriptHandler (
+OSErr
+ScriptHandler(
     const AppleEvent * event,
     AppleEvent * reply,
     long handlerRefcon)
 {
-    OSErr theErr;
+    OSStatus theErr;
     AEDescList theDesc;
     int tclErr = -1;
     Tcl_Interp *interp;
@@ -409,98 +490,100 @@ ScriptHandler (
      * The do script event receives one parameter that should be data or a file.
      */
     theErr = AEGetParamDesc(event, keyDirectObject, typeWildCard,
-            &theDesc);
+	    &theDesc);
     if (theErr != noErr) {
-        sprintf(errString, "AEDoScriptHandler: GetParamDesc error %d", theErr);
-        theErr = AEPutParamPtr(reply, keyErrorString, typeChar, errString,
-                strlen(errString));
+	sprintf(errString, "AEDoScriptHandler: GetParamDesc error %ld",
+		theErr);
+	theErr = AEPutParamPtr(reply, keyErrorString, typeChar, errString,
+		strlen(errString));
     } else if (MissedAnyParameters(event)) {
-        sprintf(errString, "AEDoScriptHandler: extra parameters");
-        AEPutParamPtr(reply, keyErrorString, typeChar, errString,
-                strlen(errString));
-        theErr = -1771;
+	sprintf(errString, "AEDoScriptHandler: extra parameters");
+	AEPutParamPtr(reply, keyErrorString, typeChar, errString,
+		strlen(errString));
+	theErr = -1771;
     } else {
-        if (theDesc.descriptorType == (DescType)typeChar) {
-            Tcl_DString encodedText;
-            short i;
-            Size  size;
-            char  * data;
-            
-            size = AEGetDescDataSize(&theDesc);
-            
-            data = (char *)ckalloc(size + 1);
-            if ( !data ) {
-                theErr = -1771;
-            }
-            else {
-                   AEGetDescData(&theDesc,data,size);
-                   data [ size ] = 0;
-                   for (i = 0; i < size; i++)
-                    if (data[i] == '\r')
-                     data[i] = '\n';
-                   AEReplaceDescData(theDesc.descriptorType, data, 
-		           size + 1, &theDesc);
-            }
-            Tcl_ExternalToUtfDString(NULL, data, size,
-                    &encodedText);
-            tclErr = Tcl_GlobalEval(interp, Tcl_DStringValue(&encodedText));
-            Tcl_DStringFree(&encodedText);
-        } else if (theDesc.descriptorType == (DescType)typeAlias) {
-            Boolean dummy;
-            FSRef file;
-            AliasPtr    alias;
-            Size        theSize;
+	if (theDesc.descriptorType == (DescType)typeChar) {
+	    Tcl_DString encodedText;
+	    short i;
+	    Size  size;
+	    char  * data;
 
-            theSize = AEGetDescDataSize(&theDesc);
-            alias = (AliasPtr) ckalloc(theSize);
-            if (alias) {
-                AEGetDescData (&theDesc, alias, theSize);
-            
-                theErr = FSResolveAlias(NULL, &alias,
-                        &file, &dummy);
-                ckfree((char*)alias);
-            } else {
-                theErr = memFullErr;
-            }
-            if (theErr == noErr) {
-                Tcl_DString scriptName;
-                theErr = FSRefToDString(&file, &scriptName);
-                if (theErr == noErr) {
-                    Tcl_EvalFile(interp, Tcl_DStringValue(&scriptName));
-                    Tcl_DStringFree(&scriptName);
-                }
-            } else {
-                sprintf(errString, "AEDoScriptHandler: file not found");
-                AEPutParamPtr(reply, keyErrorString, typeChar,
-                        errString, strlen(errString));
-            }
-        } else {
-            sprintf(errString,
-                    "AEDoScriptHandler: invalid script type '%-4.4s', must be 'alis' or 'TEXT'",
-                    (char *)(&theDesc.descriptorType));
-            AEPutParamPtr(reply, keyErrorString, typeChar,
-                    errString, strlen(errString));
-            theErr = -1770;
-        }
+	    size = AEGetDescDataSize(&theDesc);
+
+	    data = (char *)ckalloc(size + 1);
+	    if ( !data ) {
+		theErr = -1771;
+	    }
+	    else {
+		   AEGetDescData(&theDesc,data,size);
+		   data [ size ] = 0;
+		   for (i = 0; i < size; i++)
+		    if (data[i] == '\r')
+		     data[i] = '\n';
+		   AEReplaceDescData(theDesc.descriptorType, data,
+			   size + 1, &theDesc);
+	    }
+	    Tcl_ExternalToUtfDString(NULL, data, size,
+		    &encodedText);
+	    tclErr = Tcl_EvalEx(interp, Tcl_DStringValue(&encodedText),
+		    Tcl_DStringLength(&encodedText), TCL_EVAL_GLOBAL);
+	    Tcl_DStringFree(&encodedText);
+	} else if (theDesc.descriptorType == (DescType)typeAlias) {
+	    Boolean dummy;
+	    FSRef file;
+	    AliasPtr	alias;
+	    Size	theSize;
+
+	    theSize = AEGetDescDataSize(&theDesc);
+	    alias = (AliasPtr) ckalloc(theSize);
+	    if (alias) {
+		AEGetDescData (&theDesc, alias, theSize);
+
+		theErr = FSResolveAlias(NULL, &alias,
+			&file, &dummy);
+		ckfree((char*)alias);
+	    } else {
+		theErr = memFullErr;
+	    }
+	    if (theErr == noErr) {
+		Tcl_DString scriptName;
+		theErr = FSRefToDString(&file, &scriptName);
+		if (theErr == noErr) {
+		    Tcl_EvalFile(interp, Tcl_DStringValue(&scriptName));
+		    Tcl_DStringFree(&scriptName);
+		}
+	    } else {
+		sprintf(errString, "AEDoScriptHandler: file not found");
+		AEPutParamPtr(reply, keyErrorString, typeChar,
+			errString, strlen(errString));
+	    }
+	} else {
+	    sprintf(errString,
+		    "AEDoScriptHandler: invalid script type '%-4.4s', must be 'alis' or 'TEXT'",
+		    (char *)(&theDesc.descriptorType));
+	    AEPutParamPtr(reply, keyErrorString, typeChar,
+		    errString, strlen(errString));
+	    theErr = -1770;
+	}
     }
 
     /*
      * If we actually go to run Tcl code - put the result in the reply.
      */
     if (tclErr >= 0) {
-        if (tclErr == TCL_OK)  {
-            AEPutParamPtr(reply, keyDirectObject, typeChar,
-                Tcl_GetStringResult(interp),
-                strlen(Tcl_GetStringResult(interp)));
-        } else {
-            AEPutParamPtr(reply, keyErrorString, typeChar,
-                Tcl_GetStringResult(interp),
-                strlen(Tcl_GetStringResult(interp)));
-            AEPutParamPtr(reply, keyErrorNumber, typeInteger,
-                (Ptr) &tclErr, sizeof(int));
-        }
+	if (tclErr == TCL_OK)  {
+	    AEPutParamPtr(reply, keyDirectObject, typeChar,
+		Tcl_GetStringResult(interp),
+		strlen(Tcl_GetStringResult(interp)));
+	} else {
+	    AEPutParamPtr(reply, keyErrorString, typeChar,
+		Tcl_GetStringResult(interp),
+		strlen(Tcl_GetStringResult(interp)));
+	    AEPutParamPtr(reply, keyErrorNumber, typeInteger,
+		(Ptr) &tclErr, sizeof(int));
+	}
     }
-        
+
     AEDisposeDesc(&theDesc);
 
     return theErr;
@@ -511,22 +594,22 @@ ScriptHandler (
  *
  * ReallyKillMe --
  *
- *      This proc tries to kill the shell by running exit,
- *      called from an event scheduled by the "Quit" AppleEvent handler.
+ *	This proc tries to kill the shell by running exit,
+ *	called from an event scheduled by the "Quit" AppleEvent handler.
  *
  * Results:
- *        Runs the "exit" command which might kill the shell.
+ *	Runs the "exit" command which might kill the shell.
  *
  * Side effects:
- *        None.
+ *	None.
  *
  *----------------------------------------------------------------------
  */
 
-static int 
+static int
 ReallyKillMe(
     Tcl_Event *eventPtr,
-    int flags) 
+    int flags)
 {
     Tcl_Interp *interp = ((KillEvent *) eventPtr)->interp;
     Tcl_CmdInfo dummy;
@@ -543,28 +626,28 @@ ReallyKillMe(
  *
  * MissedAnyParameters --
  *
- *        Checks to see if parameters are still left in the event.  
+ *	Checks to see if parameters are still left in the event.
  *
  * Results:
- *        True or false.
+ *	True or false.
  *
  * Side effects:
- *        None.
+ *	None.
  *
  *----------------------------------------------------------------------
  */
- 
-static int 
+
+int
 MissedAnyParameters(
     const AppleEvent *theEvent)
 {
    DescType returnedType;
    Size actualSize;
-   OSErr err;
+   OSStatus err;
+
+   err = ChkErr(AEGetAttributePtr, theEvent, keyMissedKeywordAttr,
+	   typeWildCard, &returnedType, NULL, 0, &actualSize);
 
-   err = AEGetAttributePtr(theEvent, keyMissedKeywordAttr, typeWildCard, 
-                   &returnedType, NULL, 0, &actualSize);
-   
    return (err != errAEDescNotFound);
 }
 
@@ -573,28 +656,28 @@ MissedAnyParameters(
  *
  * FSRefToDString --
  *
- *      Get a POSIX path from an FSRef.
+ *	Get a POSIX path from an FSRef.
  *
  * Results:
- *      In the parameter ds.
+ *	In the parameter ds.
  *
  * Side effects:
- *      None.
+ *	None.
  *
  *----------------------------------------------------------------------
  */
 
-static OSErr
+OSStatus
 FSRefToDString(
     const FSRef *fsref,
     Tcl_DString *ds)
 {
     UInt8 fileName[PATH_MAX+1];
-    OSErr err;
+    OSStatus err;
 
-    err = FSRefMakePath(fsref, fileName, sizeof(fileName));
+    err = ChkErr(FSRefMakePath, fsref, fileName, sizeof(fileName));
     if (err == noErr) {
-        Tcl_ExternalToUtfDString(NULL, (char*) fileName, -1, ds);
+	Tcl_ExternalToUtfDString(NULL, (char*) fileName, -1, ds);
     }
     return err;
 }
